@@ -26,6 +26,7 @@
 #include <string.h>
 #include <errno.h>
 #include <inttypes.h>
+#include <ctype.h>
 
 /* Gnulib. */
 #include "progname.h"
@@ -90,11 +91,16 @@ verbose_hotp (uint64_t moving_factor)
 }
 
 static void
-verbose_totp (time_t t0, time_t time_step_size, time_t when)
+verbose_totp (oath_totp_flags flags, time_t t0, time_t time_step_size,
+	      time_t when)
 {
   struct tm tmp;
   char outstr[200];
 
+  printf ("TOTP mode: %s\n", flags == OATH_TOTP_HMAC_SHA256 ? "SHA256" :
+	  flags == OATH_TOTP_HMAC_SHA512 ? "SHA512" :
+	  flags == 0 ? "SHA1" : "invalid");
+
   if (gmtime_r (&t0, &tmp) == NULL)
     error (EXIT_FAILURE, 0, "gmtime_r");
 
@@ -250,6 +256,8 @@ main (int argc, char *argv[])
 
   if (args_info.totp_given)
     {
+      char *p;
+
       now = time (NULL);
       when = parse_time (args_info.now_arg, now);
       t0 = parse_time (args_info.start_time_arg, now);
@@ -266,13 +274,15 @@ main (int argc, char *argv[])
 	error (EXIT_FAILURE, 0, "cannot parse time `%s'",
 	       args_info.time_step_size_arg);
 
-      if (strcmp (args_info.totp_arg, "sha256") == 0)
+      for (p = args_info.totp_arg; *p ; p++)
+	*p = toupper (*p);
+      if (strcmp (args_info.totp_arg, "SHA256") == 0)
 	totpflags = OATH_TOTP_HMAC_SHA256;
-      else if (strcmp (args_info.totp_arg, "sha512") == 0)
+      else if (strcmp (args_info.totp_arg, "SHA512") == 0)
 	totpflags = OATH_TOTP_HMAC_SHA512;
 
       if (args_info.verbose_flag)
-	verbose_totp (t0, time_step_size, when);
+	verbose_totp (totpflags, t0, time_step_size, when);
     }
   else
     {
