@@ -40,14 +40,14 @@ dotest()
 	cmp="!="
     fi
 
-    got="`$OATHTOOL $params 2> /dev/null`"
-    err="`$OATHTOOL $params 2>&1 > /dev/null`"
+    got="$($OATHTOOL $params 2> /dev/null)"
+    err="$($OATHTOOL $params 2>&1 > /dev/null)"
 
-    if test "`echo $got`" $cmp "$expect"; then
+    if test "`echo $got`" $cmp "`echo $expect`"; then
 	echo FAIL: oathtool $params
-	echo expected: -$expect-
-	echo got: -$got-
-	echo err: -$err-
+	echo "expected: -$expect-"
+	echo "got:      -$got-"
+	echo "stderr:   -$err-"
 	exit 1
     else
 	echo PASS oathtool $params
@@ -86,8 +86,14 @@ dotest "-c 4 -w 4 -d 7 00 964213" "2" fail
 dotest "-c 4 -d 7 00 964213" "2" fail
 dotest "--totp $sha1key -N @59 -d8" "94287082"
 dotest "--totp=sha256 $sha256key -N @59 -d8" "46119246"
+dotest "--totp=Sha256 $sha256key -N @59 -d8" "46119246"
+dotest "--totp=SHA256 $sha256key -N @59 -d8" "46119246"
 dotest "--totp=sha512 $sha512key -N @59 -d8" "90693936"
+dotest "--totp=sHa512 $sha512key -N @59 -d8" "90693936"
+dotest "--totp=SHA512 $sha512key -N @59 -d8" "90693936"
 dotest "--totp $sha1key -N @1111111109 -d8" "07081804"
+dotest "--totp=sha1 $sha1key -N @1111111109 -d8" "07081804"
+dotest "--totp=SHA1 $sha1key -N @1111111109 -d8" "07081804"
 dotest "--totp=sha256 $sha256key -N @1111111109 -d8" "68084774"
 dotest "--totp=sha512 $sha512key -N @1111111109 -d8" "25091201"
 dotest "--totp $sha1key -N @1111111111 -d8" "14050471"
@@ -107,5 +113,24 @@ dotest "--totp --now @1111111109 -w 10 $sha1key 14050471" "1"
 dotest "--totp --now @1111111109 -w 5 $sha1key" "081804 050471 266759 306183 466594 754889"
 dotest "--totp=sha256 --now @1111111109 -w 5 $sha256key" "084774 062674 267535 096086 328915 956967"
 dotest "--hotp --counter 1099511627776 00" "363425"
+dotest "--verbose 00" "Hex secret: 00
+Base32 secret: AA======
+Digits: 6
+Window size: 0
+Start counter: 0x0 (0)
+
+328482"
+dotest " --verbose --totp=SHA512 --now @0 00" "Hex secret: 00
+Base32 secret: AA======
+Digits: 6
+Window size: 0
+TOTP mode: SHA512
+Step size (seconds): 30
+Start time: 1970-01-01 00:00:00 UTC (0)
+Current time: 1970-01-01 00:00:00 UTC (0)
+Counter: 0x0 (0)
+
+674061
+"
 
 exit 0
