@@ -1,6 +1,6 @@
 /*
  * test-pam_oath-root.c - self-test PAM module as root
- * Copyright (C) 2011-2016 Simon Josefsson
+ * Copyright (C) 2011-2020 Simon Josefsson
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -127,6 +127,11 @@ main (int argc, char **argv)
 	}
 
       rc = pam_authenticate (pamh, 0);
+      if (rc == PAM_MODULE_UNKNOWN)
+	{
+	  fprintf (stderr, "pam_oath.so not found in /lib/*/security/.\n");
+	  return 77;
+	}
       if (rc != tv[loop].expectrc)
 	{
 	  printf ("pam_authenticate failed loop %ld rc %d: %s\n", loop, rc,
