@@ -1,6 +1,6 @@
 /*
  * pskctool.c - Manage Portable Symmetric Key Container (PSKC) data.
- * Copyright (C) 2012-2016 Simon Josefsson
+ * Copyright (C) 2012-2020 Simon Josefsson
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -94,9 +94,9 @@ get_container (const struct gengetopt_args_info *args_info)
 	   pskc_strerror (rc));
 
   if (filename)
-    buffer = read_binary_file (filename, &len);
+    buffer = read_file (filename, RF_BINARY | RF_SENSITIVE, &len);
   else
-    buffer = fread_file (stdin, &len);
+    buffer = fread_file (stdin, RF_BINARY | RF_SENSITIVE, &len);
   if (buffer == NULL)
     error (EXIT_FAILURE, errno, "read");
 
